import type { AspectMain } from '@teambit/aspect';
import { ComponentType } from 'react';
import { AspectDefinition } from '@teambit/aspect-loader';
import { CacheMain } from '@teambit/cache';
import { CLIMain } from '@teambit/cli';
import type { ComponentMain } from '@teambit/component';
import { ExpressMain } from '@teambit/express';
import type { GraphqlMain } from '@teambit/graphql';
import { SlotRegistry, Harmony } from '@teambit/harmony';
import { Logger, LoggerMain } from '@teambit/logger';
import { PubsubMain } from '@teambit/pubsub';
import webpack from 'webpack';
import { UIRoot } from './ui-root';
import { UIServer } from './ui-server';
import { StartPlugin } from './start-plugin';
export declare type UIDeps = [PubsubMain, CLIMain, GraphqlMain, ExpressMain, ComponentMain, CacheMain, LoggerMain, AspectMain];
export declare type UIRootRegistry = SlotRegistry<UIRoot>;
export declare type OnStart = () => Promise<undefined | ComponentType<{}>>;
export declare type StartPluginSlot = SlotRegistry<StartPlugin>;
export declare type PublicDirOverwrite = (uiRoot: UIRoot) => Promise<string | undefined>;
export declare type BuildMethodOverwrite = (name: string, uiRoot: UIRoot, rebuild?: boolean) => Promise<string>;
export declare type OnStartSlot = SlotRegistry<OnStart>;
export declare type PublicDirOverwriteSlot = SlotRegistry<PublicDirOverwrite>;
export declare type BuildMethodOverwriteSlot = SlotRegistry<BuildMethodOverwrite>;
export declare type UIConfig = {
    port?: number;
    portRange: [number, number];
    host: string;
    publicDir: string;
};
export declare type RuntimeOptions = {
    verbose?: boolean;
    uiRootName?: string;
    pattern?: string;
    dev?: boolean;
    port?: number;
    rebuild?: boolean;
};
export declare class UiMain {
    private pubsub;
    private config;
    private graphql;
    private uiRootSlot;
    private express;
    private onStartSlot;
    private publicDirOverwriteSlot;
    private buildMethodOverwriteSlot;
    private componentExtension;
    private cache;
    private logger;
    private harmony;
    private startPluginSlot;
    constructor(pubsub: PubsubMain, config: UIConfig, graphql: GraphqlMain, uiRootSlot: UIRootRegistry, express: ExpressMain, onStartSlot: OnStartSlot, publicDirOverwriteSlot: PublicDirOverwriteSlot, buildMethodOverwriteSlot: BuildMethodOverwriteSlot, componentExtension: ComponentMain, cache: CacheMain, logger: Logger, harmony: Harmony, startPluginSlot: StartPluginSlot);
    publicDir(uiRoot: UIRoot): Promise<string>;
    build(uiRootName?: string): Promise<webpack.compilation.MultiStats>;
    registerStartPlugin(startPlugin: StartPlugin): this;
    private initiatePlugins;
    createRuntime({ uiRootName, pattern, dev, port, rebuild, verbose }: RuntimeOptions): Promise<UIServer>;
    getPort(port?: number): Promise<number>;
    private createUiServerStartedEvent;
    registerOnStart(onStartFn: OnStart): this;
    registerBuildUIOverwrite(fn: BuildMethodOverwrite): this;
    registerPublicDirOverwrite(fn: PublicDirOverwrite): this;
    private getOverwriteBuildFn;
    private getOverwritePublic;
    invokeOnStart(): Promise<ComponentType[]>;
    registerUiRoot(uiRoot: UIRoot): void;
    getUi(uiRootName?: string): [string, UIRoot];
    getUiRootOrThrow(uiRootName: string): UIRoot;
    createLink(aspectDefs: AspectDefinition[], rootExtensionName: string): Promise<string>;
    generateRoot(aspectDefs: AspectDefinition[], rootExtensionName: string, runtimeName?: string, rootAspect?: string): Promise<string>;
    private selectPort;
    private buildUI;
    buildUiHash(uiRoot: UIRoot, runtime?: string): Promise<string>;
    buildIfChanged(name: string, uiRoot: UIRoot, force: boolean | undefined): Promise<string>;
    clearConsole(): void;
    buildIfNoBundle(name: string, uiRoot: UIRoot): Promise<void>;
    private openBrowser;
    static defaultConfig: {
        publicDir: string;
        portRange: number[];
        host: string;
    };
    static runtime: import("@teambit/harmony").RuntimeDefinition;
    static dependencies: import("@teambit/harmony").Aspect[];
    static slots: (((registerFn: () => string) => SlotRegistry<UIRoot>) | ((registerFn: () => string) => SlotRegistry<OnStart>) | ((registerFn: () => string) => SlotRegistry<PublicDirOverwriteSlot>) | ((registerFn: () => string) => SlotRegistry<BuildMethodOverwriteSlot>) | ((registerFn: () => string) => SlotRegistry<StartPlugin>))[];
    static provider([pubsub, cli, graphql, express, componentExtension, cache, loggerMain]: UIDeps, config: any, [uiRootSlot, onStartSlot, publicDirOverwriteSlot, buildMethodOverwriteSlot, proxyGetterSlot]: [
        UIRootRegistry,
        OnStartSlot,
        PublicDirOverwriteSlot,
        BuildMethodOverwriteSlot,
        StartPluginSlot
    ], harmony: Harmony): Promise<UiMain>;
}
